% llrkernel.m -- Locar linear (LLR) regression estimator, MATRIX VERSION
%
% Parameters:
%		xx		point (or column vector of points) where the estimator is to be evaluated
%		x		column vector of sample locations
%     h     smoothing parameter
%		K		(optional) one-dimensional kernel function, defaults to 'gauss'
%
% Returns:
%		G		matrix for evaluating LLR estimator, as G*y
%     U     matrix for evaluating LLR estimator derivative, as U*y
%     B     matrix for evaluating local slope, as B*y

function [G,U,B]=llrkernel(xx,x,h,K)

if nargin<4
   K='gauss';
end

N = length(xx);		% number of evaluation points
n = length(x);			% number of sample points

if nargout >= 3,
   [G,U,B] = llr(xx,x,eye(n),h,K);
elseif nargout >= 2,
   [G,U] = llr(xx,x,eye(n),h,K);
else
   G = llr(xx,x,eye(n),h,K);
end

