% RESID_GSJ   Estimate residual variance through second differencing
%
% According to G&S eq. 3.18,
% and Gasser-Sroka-Jennen-Steinmetz (1986).
%
% Parameters:
%    X   x-coordinates of the data
%    Y   y-coordinates of the data
%
% Returns:
%    S2      estimated residual variance
%    epshat  vector of estimated residuals

function [S2,epshat]=resid_gsj(X,Y)

n = length(X);

NEXT = 3:n;
THIS = 2:n-1;
PREV = 1:n-2;

a = (X(NEXT)-X(THIS)) ./ (X(NEXT)-X(PREV));
b = (X(THIS)-X(PREV)) ./ (X(NEXT)-X(PREV));
c2 = 1 ./ (a.^2 + b.^2 + 1);

epshat = a.*Y(PREV) + b.*Y(NEXT) - Y(THIS);
S2 = sum(c2 .* epshat.^2) / (n-2);

% scale epshat so that their standard deviation is sqrt(S2), i.e. our stdev estimate
%epshat = epshat * sqrt(S2) / std(epshat);
